@@ -1,4 +1,8 @@
 # -*- coding: utf-8 -*-
+try:
+    from libs.modelmixins import UrlMixin
+except ImportError:
+    from cryotec_server.libs.modelmixins import UrlMixin
 try:
     from django.db import models
 except ImportError:
@@ -32,4 +36,4 @@ class ContactFace(models.Model):
     
     class Meta:
         verbose_name = "Контактное лицо"
-        verbose_name_plural = "Контактное лицо"
\ No newline at end of file
+        verbose_name_plural = "Контактное лицо"
